***********************************
  The :mod:`htsql_sqlite` package
***********************************

.. automodule:: htsql_sqlite
   :members:
.. automodule:: htsql_sqlite.connect
   :members:
.. automodule:: htsql_sqlite.domain
   :members:
.. automodule:: htsql_sqlite.export
   :members:
.. automodule:: htsql_sqlite.introspect
   :members:
.. automodule:: htsql_sqlite.split_sql
   :members:

